==> ssp-center-api-0.6.12-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/prePayInvoiceRecord/PrePayInvoiceRecordOrderDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.prePayInvoiceRecord;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * 预付款订单已开票金额
 *
 * @author zhangzhenghe
 * @since 2019-10-22 15:04
 */
public class PrePayInvoiceRecordOrderDTO implements Serializable {

    private static final long serialVersionUID = 6461357708897100518L;

    /**
     * 预付款单号
     */
    private Long prePayOrderId;

    /**
     * 杭州已开票金额
     */
    private Long hzBilledAmountOrder;
    /**
     * 霍尔果斯已开票金额
     */
    private Long hegsBilledAmountOrder;
    /**
     * 霍城兑捷已开票金额
     */
    private Long hcdjBilledAmountOrder;
    /**
     * 已开票金额
     */
    private Long billedAmountOrder;

    public Long getPrePayOrderId() {
        return prePayOrderId;
    }

    public void setPrePayOrderId(Long prePayOrderId) {
        this.prePayOrderId = prePayOrderId;
    }

    public Long getHzBilledAmountOrder() {
        return hzBilledAmountOrder;
    }

    public void setHzBilledAmountOrder(Long hzBilledAmountOrder) {
        this.hzBilledAmountOrder = hzBilledAmountOrder;
    }

    public Long getHegsBilledAmountOrder() {
        return hegsBilledAmountOrder;
    }

    public void setHegsBilledAmountOrder(Long hegsBilledAmountOrder) {
        this.hegsBilledAmountOrder = hegsBilledAmountOrder;
    }

    public Long getHcdjBilledAmountOrder() {
        return hcdjBilledAmountOrder;
    }

    public void setHcdjBilledAmountOrder(Long hcdjBilledAmountOrder) {
        this.hcdjBilledAmountOrder = hcdjBilledAmountOrder;
    }

    public Long getBilledAmountOrder() {
        return billedAmountOrder;
    }

    public void setBilledAmountOrder(Long billedAmountOrder) {
        this.billedAmountOrder = billedAmountOrder;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> ssp-center-api-1.1.20-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/prePayInvoiceRecord/PrePayInvoiceRecordOrderDTO.java <==
package cn.com.duiba.tuia.ssp.center.api.dto.prePayInvoiceRecord;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;

/**
 * 预付款订单已开票金额
 *
 * @author zhangzhenghe
 * @since 2019-10-22 15:04
 */
public class PrePayInvoiceRecordOrderDTO implements Serializable {

    private static final long serialVersionUID = 6461357708897100518L;

    /**
     * 预付款单号
     */
    private Long prePayOrderId;

    /**
     * 杭州已开票金额
     */
    private Long hzBilledAmountOrder;
    /**
     * 霍尔果斯已开票金额
     */
    private Long hegsBilledAmountOrder;
    /**
     * 霍城兑捷已开票金额
     */
    private Long hcdjBilledAmountOrder;
    /**
     * 已开票金额
     */
    private Long billedAmountOrder;

    /**
     * 账号ID
     */
    private Long mediaId;

    public Long getPrePayOrderId() {
        return prePayOrderId;
    }

    public void setPrePayOrderId(Long prePayOrderId) {
        this.prePayOrderId = prePayOrderId;
    }

    public Long getHzBilledAmountOrder() {
        return hzBilledAmountOrder;
    }

    public void setHzBilledAmountOrder(Long hzBilledAmountOrder) {
        this.hzBilledAmountOrder = hzBilledAmountOrder;
    }

    public Long getHegsBilledAmountOrder() {
        return hegsBilledAmountOrder;
    }

    public void setHegsBilledAmountOrder(Long hegsBilledAmountOrder) {
        this.hegsBilledAmountOrder = hegsBilledAmountOrder;
    }

    public Long getHcdjBilledAmountOrder() {
        return hcdjBilledAmountOrder;
    }

    public void setHcdjBilledAmountOrder(Long hcdjBilledAmountOrder) {
        this.hcdjBilledAmountOrder = hcdjBilledAmountOrder;
    }

    public Long getBilledAmountOrder() {
        return billedAmountOrder;
    }

    public void setBilledAmountOrder(Long billedAmountOrder) {
        this.billedAmountOrder = billedAmountOrder;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
